<template>
    <div :id="id" class="flow-history">
      <template
        v-if="field.displayType == Constant.PermissionType_HIDDEN || field.textType == 'hidden'"
      >
        <!-- 隐藏 TODO:注意，隐藏时不应该有hidden的field存在，有安全问题，以后要改过来：Jarod -->
        <input type="hidden" v-model="field.value" />
        <div v-if="field.mobile&&field.hiddenValue">
          <div class="titleName">
            {{field.discript?field.discript:field.name}}
          </div>
          <div class="view-li">
            <div class="view-li-right">
              {{field.hiddenValue}}
            </div>
          </div>
        </div>
      </template>
      
      <!--只读-->
      <template v-else-if="field.textType == 'readonly' || field.displayType == Constant.PermissionType_READONLY || field.displayType == Constant.PermissionType_DISABLED">
        <template v-if="field.readOnlyShowValOnly">
          <!-- 只读（文本模式） -->
          <div class="titleName">
            {{field.discript?field.discript:field.name}}
          </div>
          <div :data="tableData">
            <div v-for="(item, index) in tableData" :key="item.historyId" class="view-li">
              <div class="view-li-left">
                <div class="reminder-num">{{index+1}}</div>
              </div>
              <div class="view-li-right">
                <div class="reminder-nodeName">{{$t('nodeName')}}：{{item.nodeName}}</div>
                <div class="reminder-name">{{$t('reminder')}}：{{item.userName}}</div>
                <div class="reminder-time">{{$t('reminderTime')}}：{{item.processTime}}</div>
                <div class="reminder-content">{{$t('content')}}：{{item.content}}</div>
              </div>
            </div>
          </div>
        </template>
        <template v-else>
          <!-- 只读（控件模式） -->
          <div class="titleName">
            {{field.discript?field.discript:field.name}}
          </div>
          <div :data="tableData">
            <div v-for="(item, index) in tableData" :key="item.historyId" class="view-li">
              <div class="view-li-left">
                <div class="reminder-num">{{index+1}}</div>
              </div>
              <div class="view-li-right">
                <div class="reminder-nodeName">{{$t('nodeName')}}：{{item.nodeName}}</div>
                <div class="reminder-name">{{$t('reminder')}}：{{item.userName}}</div>
                <div class="reminder-time">{{$t('reminderTime')}}：{{item.processTime}}</div>
                <div class="reminder-content">{{$t('content')}}：{{item.content}}</div>
              </div>
            </div>
          </div>
        </template>
      </template>

      <template v-else-if="field.displayType == Constant.PermissionType_MODIFY">
        <!-- 可编辑 -->
        <div class="titleName">
          {{field.discript?field.discript:field.name}}
        </div>
        <div :data="tableData">
          <div v-for="(item, index) in tableData" :key="item.historyId" class="view-li">
            <div class="view-li-left">
              <div class="reminder-num">{{index+1}}</div>
            </div>
            <div class="view-li-right">
              <div class="reminder-nodeName">{{$t('nodeName')}}：{{item.nodeName}}</div>
              <div class="reminder-name">{{$t('reminder')}}：{{item.userName}}</div>
              <div class="reminder-time">{{$t('reminderTime')}}：{{item.processTime}}</div>
              <div class="reminder-content">{{$t('content')}}：{{item.content}}</div>
            </div>
          </div>
        </div>
      </template>
    </div>
</template>

<script>
import Constant from "@/Constant.js";
import API from "@/api.js";
export default {
  name: "o-flow-reminder-history",
  props: ["id"],
  computed: {
    field: function() {
      return this.$parent.findField(this.id);
    }
  },
  mounted() {
    this.getFlowHistory();
  },
  methods: {
    getFlowHistory() {
      let appId = this.$root.appid;
      let docId = this.field.docId;
      API.getRemindHistorys(appId, docId, {
        onSucess: response => {
          let flowData = response.data.data;
          flowData.forEach(item => {
            if(item.processTime) {
              let date = new Date(item.processTime);
              let Y = date.getFullYear() + '-';
              let M = (date.getMonth()+1 < 10 ? '0'+(date.getMonth()+1) : date.getMonth()+1) + '-';
              let D = (date.getDate() < 10 ? '0'+date.getDate() : date.getDate()) + ' ';
              let h = (date.getHours() < 10 ? '0'+date.getHours() : date.getHours()) + ':';
              let m = (date.getMinutes() < 10 ? '0'+date.getMinutes() : date.getMinutes()) + ':';
              let s = (date.getSeconds() < 10 ? '0'+date.getSeconds() : date.getSeconds());
              
              let dateTime = Y + M + D + h + m + s;
              item.processTime = dateTime
            }
          });
          
          this.tableData = response.data.data;
        }
      });
    }
  },
  data: function() {
    return {
      Constant,

      tableData: []
    };
  }
};
</script>
